/*
 * QUSOFT MICROSYSTMES
 * Moka
 * Copyright 2002 Frdric Brown
 */

/*
 *  This file is part of Moka.
 *
 *  Moka is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Moka is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Moka; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package moka.event;

import moka.lang.Object;

/**
 * The Interrupt interfaces for executing code while a thread is running.
 *
 * @author  Frdric Brown
 * @version 1.1, 2002-11-03
 * @since   MDK1.0a
 */
public abstract class Interrupt extends moka.lang.Object {
	/** A flag to indicate if this timer is registered. */
	private boolean registered;

	/** Setting this flag to true will stop the interrupts execution.*/
	public static boolean busy;
	
	/** A flag to indicate if there is an interruption underway. Should be only read.*/
	//public static boolean interrupting;

	/**
	 * Creates a new Interrupt.
	 *
	 * @since MDK2.1
	 */
	public Interrupt () {
	}

	/**
	 * Called when an InterruptEvent occurs.  This method
	 * checks the current interrupt then increment the interrupts' index.
	 * @since MDK2.1
	 */
	private static void onInterrupt () {
	}

	
	/**
	 * Registers the specified interrupt.
	 *
	 * @param item the interrupt to be registered.
	 * @since MDK2.1
	 */
	public static native void register (Interrupt item) ;

	/**
	 * Unregisters the specified interrupt.
	 *
	 * @param item the interrupt to be unregistered.
	 * @since MDK2.1
	 */
	public static native void unregister (Interrupt item) ;

    /**
     * Frees the ressources used by this Interrupt.
     *
     * @since MDK2.1
     */
	public void finalize () {
	}

	/**
	 * Used by a thread to verify if this interrupt should be executed.
	 *
	 * @return true if this interrupt should be executed
	 */
	public abstract boolean check ();

	/**
	 * Handles the code to execute when this object interrupts.
	 */
	public abstract void run ();
}