/*
 * QUSOFT MICROSYSTMES
 * Moka
 * Copyright 2004 Frdric Brown
 */

/*
 *  This file is part of Moka API.
 *
 *  Moka API is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Moka API is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Moka API; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package moka.io;

import moka.lang.*;
import moka.lang.Object;
import moka.lang.System;
import moka.lang.ushort;

/**
 * Class <code>RowRead</code> is used to get low-level input from the
 * keyboard. Its features are less powerfull than the ones of the Keyboard class,
 * but it is more efficient. The key static methods provided in this class are
 * realy fast ways to determine if a particular key is pressed.
 *
 * @author  Frdric Brown
 * @version 1.0, 2004-03-11
 * @since   MDK2.2
 */
public final class RowRead extends moka.lang.Object {

	/**
	 * Enable RowRead operation. Saves then disable interupt handlers 1 and 5.
	 */
	public static native void enable() ;

	/**
	 * Disable RowRead operation. Restores interupt handlers 1 and 5.
	 */
	public static native void disable() ;

	/**
	 * Handle low level keyboard reading for simultaneous reading of more than one key. This method is hardware dependant, use the
	 * key methods to overcome dependance.
	 *
	 * @return a ushort which all bits (cols) corresponding to keys which are being held down are set.
	 * @param row Setting a bit in row masks the corresponding row of the keyboard from being read, so if row is zero, all rows are read at the same time.
	 */
	public static ushort rowRead ( UShort row ) ;

	/**
	 * Handle low level keyboard reading for single keys. This method is hardware dependant, use the
	 * key methods to overcome dependance.
	 *
	 * @return true if the key is pressed, false otherwize.
	 * @param row The row to read.
	 * @param col The column to read.
	 */
	public static boolean keyTest (short row, short col) {
		return FALSE;
	}

	/**
	 * Checks if the DIAMOND key is pressed. Value is true if the key is pressed, false otherwize.
	 */
	/* Alias implemented */
	public static  boolean key_Diamnd;

	/**
	 * Checks if the SHIFT key is pressed. Value is true if the key is pressed, false otherwize.
	 */
	/* Alias implemented */
	public static  boolean key_Shift;

	/**
	 * Checks if the 2ND key is pressed. Value is true if the key is pressed, false otherwize.
	 */
	/* Alias implemented */
	public static  boolean key_2nd;

	/**
	 * Checks if the APPS key is pressed. Value is true if the key is pressed, false otherwize.
	 */
	/* Alias implemented */
	public static  boolean key_APPS;

	/**
	 * Checks if the ESC key is pressed. Value is true if the key is pressed, false otherwize.
	 */
	/* Alias implemented */
	public static  boolean key_ESC;

	/**
	 * Checks if the RIGHT key is pressed. Value is true if the key is pressed, false otherwize.
	 */
	/* Alias implemented */
	public static  boolean key_Right;

	/**
	 * Checks if the DOWN key is pressed. Value is true if the key is pressed, false otherwize.
	 */
	/* Alias implemented */
	public static  boolean key_Down;

	/**
	 * Checks if the LEFT key is pressed. Value is true if the key is pressed, false otherwize.
	 */
	/* Alias implemented */
	public static  boolean key_Left;

	/**
	 * Checks if the UP key is pressed. Value is true if the key is pressed, false otherwize.
	 */
	/* Alias implemented */
	public static  boolean key_Up;

	/**
	 * Checks if the ENTER key is pressed. Value is true if the key is pressed, false otherwize.
	 */
	/* Alias implemented */
	public static  boolean key_ENTER;

	/**
	 * Checks if the ENTER1 key is pressed. Value is true if the key is pressed, false otherwize.
	 */
	/* Alias implemented */
	public static  boolean key_ENTER1;

	/**
	 * Checks if the ENTER2 key is pressed. Value is true if the key is pressed, false otherwize.
	 */
	/* Alias implemented */
	public static  boolean key_ENTER2;

	/**
	 * Checks if the F1 key is pressed. Value is true if the key is pressed, false otherwize.
	 */
	/* Alias implemented */
	public static  boolean key_F1;

	/**
	 * Checks if the F2 key is pressed. Value is true if the key is pressed, false otherwize.
	 */
	/* Alias implemented */
	public static  boolean key_F2;

	/**
	 * Checks if the F3 key is pressed. Value is true if the key is pressed, false otherwize.
	 */
	/* Alias implemented */
	public static  boolean key_F3;

	/**
	 * Checks if the F4 key is pressed. Value is true if the key is pressed, false otherwize.
	 */
	/* Alias implemented */
	public static  boolean key_F4;

	/**
	 * Checks if the F5 key is pressed. Value is true if the key is pressed, false otherwize.
	 */
	/* Alias implemented */
	public static  boolean key_F5;

	/**
	 * Checks if the A key is pressed. Value is true if the key is pressed, false otherwize.
	 */
	/* Alias implemented */
	public static  boolean key_A;
	/**
	 * Checks if the B key is pressed. Value is true if the key is pressed, false otherwize.
	 */
	/* Alias implemented */
	public static  boolean key_B;
	/**
	 * Checks if the C key is pressed. Value is true if the key is pressed, false otherwize.
	 */
	/* Alias implemented */
	public static  boolean key_C;
	/**
		 * Checks if the D key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_D;
	/**
		 * Checks if the E key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_E;
	/**
		 * Checks if the F key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_F;
	/**
		 * Checks if the G key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_G;
	/**
		 * Checks if the H key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_H;
	/**
		 * Checks if the I key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_I;
	/**
		 * Checks if the J key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_J;
	/**
		 * Checks if the K key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_K;
	/**
		 * Checks if the L key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_L;
	/**
		 * Checks if the M key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_M;
	/**
		 * Checks if the N key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_N;
	/**
		 * Checks if the O key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_O;
	/**
		 * Checks if the P key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_P;
	/**
		 * Checks if the Q key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_Q;
	/**
		 * Checks if the R key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_R;
	/**
		 * Checks if the S key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_S;
	/**
		 * Checks if the T key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_T;
	/**
		 * Checks if the U key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_U;
	/**
		 * Checks if the V key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_V;
	/**
		 * Checks if the W key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_W;
	/**
		 * Checks if the X key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_X;
	/**
		 * Checks if the Y key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_Y;
	/**
		 * Checks if the Z key is pressed. Value is true if the key is pressed, false otherwize.
		 */
		/* Alias implemented */
	public static  boolean key_Z;
	/**
	 * Checks if ANY key is pressed. Value is true if any key is pressed, false otherwize.
	 */
	/* Alias implemented */
	public static  boolean key_ANY;
}