/*
 * QUSOFT MICROSYSTMES
 * Moka
 * Copyright 2002 Frdric Brown
 */

/*
 *  This file is part of Moka.
 *
 *  Moka is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Moka is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Moka; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package moka.lang;

import moka.lang.Object;
import moka.lang.String;

/**
 * The <code>System</code> class contains several useful class fields
 * and methods. It cannot be instantiated.
 * <p>
 * Among the facilities provided by the <code>System</code> class
 * are input and output functions and most of the calc-dependent and AMS-dependent constants.
 *
 * @author  Frdric Brown
 * @version 1.1, 2002-10-25
 * @since   MDK1.0a
 */
 public final class System extends moka.lang.Object {

 	/** Indicate that the AMS version is AMS_1xx.*/
 	public static final short AMS_1 = 1;
 	/** Indicate that the AMS version is AMS_2xx.*/
 	public static final short AMS_2 = 2;

 	/** Indicate that the calculator model is TI89.*/
 	public static final short CALCULATOR_TI89 = 0;
 	/** Indicate that the calculator model is TI92PLUS.*/
 	public static final short CALCULATOR_TI92PLUS = 1;
 	/** Indicate that the calculator model is V200.*/
 	public static final short CALCULATOR_V200 = 3;

 	/**The AMS version (AMS_1xx or AMS_2xx)*/
 	public static short AMS;
 	/**The calculator model (TI-89, TI-92 or V200)*/
 	public static short CALCULATOR;
 	/** Base address of the ROM (0x200000 on TI-89 or V200, 0x400000 on TI-92 Plus).*/
 	public static void_p ROM_BASE;
 	/** Number of entries in TIOS jump table: may be used for determining actual AMS version (for example, it is 972 on AMS 1.05 and 1463 on AMS 2.03).*/
 	public static short ENTRIES;

	/** The number added to the key code if the Diamond key is pressed with it.*/
	public static short KEY_DIAMOND;
	/** Key code for the down arrow key.*/
	public static short  KEY_DOWN;
	/** Key code for simultaneous pressing of the up and left arrow keys.*/
	public static short KEY_UPLEFT;
	/** Key code for simultaneous pressing of the down and left arrow keys.*/
	public static short KEY_DOWNLEFT;
	/** Key code for the left arrow key.*/
	public static short  KEY_LEFT;
	/** Key code for the right arrow key.*/
	public static short KEY_RIGHT;
	/** The number added to the key code if the Shift key is pressed with it.*/
	public static short KEY_SHIFT;
	/** Key code for the up arrow key.*/
	public static short KEY_UP;
	/** Key code for simultaneous pressing on up and right arrow keys.*/
	public static short KEY_UPRIGHT;
	/** Key code for simultaneous pressing on up and right arrow keys.*/
	public static short KEY_DOWNRIGHT;
	
	/** The number of arguments passed to the program. Should be only read. */
	public static short argCount ;

	private System() {}

	/**
	 * If the status flags indicate that a help message is being displayed, this function redraws the status line, effectively removing the message.
	 *
	 * @return true if the drawing is performed, false otherwize
	 * @since MDK1.01a
	 */
	public native static boolean stEraseHelp () ;

	/**
	 * Displays a message in the status line then finalizes the String argument.
	 *
	 * @param msg The message to display in the status line
	 * @since MDK1.01a
	 */
	public native static void setStHelpMsg (String msg) ;

	/**
	 * Returns the availlable RAM memory in bytes.
	 * To be accurate, this method call the garbage collection
	 * of the RAM memory then determines the total amount
	 * of free bytes.
	 *
	 * @return The availlable RAM memory in bytes
	 * @since MDK1.01a
	 */
	public native static int getAvailRAM () ;

	/**
	 * Calls the garbage collection of the RAM memory.
	 *
	 * @since MDK1.01a
	 */
	public native static void gcRAM () ;
	/**
	 * Resets the calculator.
	 *
	 * @since MDK1.01a
	 */
	public native static void reset () ;

	/**
	 * Increases the display contrast.
	 *
	 * @since MDK1.01a
	 */
	public native static void contrastUp () ;

	/**
	 * Decreases the display contrast.
	 *
	 * @since MDK1.01a
	 */
	public native static void contrastDn () ;

	/**
	 * Turns the calculator in "low-power" state until the next interrupt occurs then returns.
	 *
	 * @since MDK1.01a
	 */
	public native static void idle () ;

	/**
	 * Turns off the calculator.
	 *
	 * @since MDK1.01a
	 */
	public native static void off () ;

	/**
	 * Clears the expression stack.
	 */
	public static native void clearEstack() ;

	/**
	 * Terminates the current program returning 0 as return value.
	 * Usualy the argument serves as a status code; by convention,
	 * a nonzero status code indicates abnormal termination.
	 */
	public static void exit () {
	}

	/**
	 * Terminates the current program returning a short as return value.
	 *
	 * @param ret The value to return
	 */
	public native static void exit (short ret) ;

	/**
	 * Terminates the current program returning an int as return value.
	 *
	 * @param ret The value to return
	 */
	public native static void exit (int ret) ;

	/**
	 * Terminates the current program returning a long as return value.
	 *
	 * @param ret The value to return
	 */
	public native static void exit (long ret) ;

	/**
	 * Terminates the current program returning a double as return value.
	 *
	 * @param ret The value to return
	 */
	public native static void exit (double ret) ;

	/**
	 * Terminates the current program returning a String as return value.
	 *
	 * @param ret The value to return
	 */
	public native static void exit (String ret) ;

	/**
	 * Initializes the argument pointer or do nothing if it is already done.
	 */
	private native static void initArgPtr () ;

	/**
	 * Returns the next argument as a short.
	 *
	 * @return the next argument as a short
	 */
	public static short getShort() {
		return (short)System.getInt();
	}

	/**
	 * Returns the next argument as a int.
	 *
	 * @return the next argument as a int
	 */
	public static int getInt() {

		return 0;
	}

	/**
	 * Returns the next argument as a long.
	 *
	 * @return the next argument as a long
	 */
	public static long getLong() {

		return 0;
	}

	/**
	 * Returns the next argument as a double.
	 *
	 * @return the next argument as a double
	 */
	public static double getDouble() {

		return 0;
	}

	/**
	 * Returns the next argument as a String.
	 *
	 * @return the next argument as a String
	 */
	public static String getString() {

		return new String();
	}

	/**
	 * Clears the screen and moves the print position to the first
	 * character of the first line.
	 */
	public native static void clrscr () ;

	/**
     * Terminates the line.
     */
    public static void println () ;

    /**
     * Prints an object.  In fact, prints the string produced by the
     * <code>toString</code> method.
     *
     * @param      obj   The <code>Object</code> to be printed
     */
    public static void print (moka.lang.Object obj) {
    }

    /**
     * Prints an object and then terminates the line.  In fact, prints the
     * string produced by the <code>toString</code> method.
     *
     * @param      obj   The <code>Object</code> to be printed
     */
    public static void println (moka.lang.Object obj) {
    }

    /**
     * Prints a String then finalize the String.
     *
     * @param      s   The <code>String</code> to be printed
     */
    public static void print (String s) {
    }

    /**
     * Prints a String and then terminates the line and finalize the String.
     *
     * @param      s   The <code>String</code> to be printed
     */
    public static void println (String s) {
    }
    /**
     * Prints an ANSI string.
     *
     * @param      s   The <code>ANSI string</code> to be printed
     */
    public static void print (char[] s) ;

    /**
     * Prints an ANSI string and then terminates the line.
     *
     * @param      s   The <code>ANSI string</code> to be printed
     */
    public static void println (char[] s) ;
    /**
     * Prints a char.
     *
     * @param      c   The <code>char</code> to be printed
     */
    public static void print (char c) {

    }

    /**
     * Prints a char and then terminates the line.
     *
     * @param      c   The <code>char</code> to be printed
     */
    public static void println (char c) {

    }

    /**
     * Prints an unsigned byte.
     *
     * @param      b   The <code>ubyte</code> to be printed
     */
    public static void print (ubyte b) {}

    /**
     * Prints an unsigned byte and then terminates the line.
     *
     * @param      s   The <code>ubyte</code> to be printed
     */
    public static void println (ubyte b) {}
    
    /**
     * Prints an unsigned short.
     *
     * @param      s   The <code>ushort</code> to be printed
     */
    /*Alias implemented for print (short s).*/
    public static void print (ushort s) {}

    /**
     * Prints an unsigned short and then terminates the line.
     *
     * @param      s   The <code>ushort</code> to be printed
     */
    public static void println (ushort s) {}
    
    /**
     * Prints an unsigned int.
     *
     * @param      i   The <code>uint</code> to be printed
     */
    /*Alias implemented for print (int i).*/
    public static void print (uint i) {}

    /**
     * Prints an unsigned int and then terminates the line.
     *
     * @param      i   The <code>uint</code> to be printed
     */
    public static void println (uint i) {}
    
    /**
     * Prints an unsigned long.
     *
     * @param      l   The <code>ulong</code> to be printed
     */
    public static void print (ulong l) {
    }

    /**
     * Prints an unsigned long and then terminates the line.
     *
     * @param      l   The <code>ulong</code> to be printed
     */
    public static void println (ulong l) {}

    /**
     * Prints a byte.
     *
     * @param      b   The <code>byte</code> to be printed
     */
    public static void print (byte b) {

    }

    /**
     * Prints a byte and then terminates the line.
     *
     * @param      s   The <code>byte</code> to be printed
     */
    public static void println (byte b) {

    }

    /**
     * Prints a short.
     *
     * @param      s   The <code>short</code> to be printed
     */
    public static void print (short s) {


    }

    /**
     * Prints a short and then terminates the line.
     *
     * @param      s   The <code>short</code> to be printed
     */
    public static void println (short s) {

    }

    /**
     * Prints an int.
     *
     * @param      i   The <code>int</code> to be printed
     */
    public static void print (int i) {


    }

    /**
     * Prints an int and then terminates the line.
     *
     * @param      i   The <code>int</code> to be printed
     */
    public static void println (int i) {

    }

    /**
     * Prints a long.
     *
     * @param      l   The <code>long</code> to be printed
     */
    public static void print (long l) {

    }

    /**
     * Prints a long and then terminates the line.
     *
     * @param      l   The <code>long</code> to be printed
     */
    public static void println (long l) {

    }

    /**
     * Prints a double.
     *
     * @param      d   The <code>double</code> to be printed
     */
    public static void print (double d) {

    }

    /**
     * Prints a double and then terminates the line.
     *
     * @param      d   The <code>double</code> to be printed
     */
    public static void println (double d) {

    }

    /**
     * Read a character from the keyboard.
     *
     * @return     The character read from the keyboard.
     */
    public native static char read () {
    	return ' ';
    }

    /**
     * Read a line of text.  A line is considered to be terminated by
     * a carriage return or when the 255 character buffer is full.
     *
     * @return     A String containing the contents of the line, not including
     *             any line-termination characters.
     */
    public static String readLine () {
    	return new String();
    }

    /**
     * Read a line of text.  A line is considered to be terminated by
     * a carriage return or when the 255 character buffer is full.
     *
     * @param	   echo if true, echos the keys pressed on the screen.
     * @return     A String containing the contents of the line, not including
     *             any line-termination characters.
     */
    public static String readLine (boolean echo) {


    	return new String();
    }

    /**
     * Executes the specified string command.  The string command object
     * is finalized before this method returns.
     *
     * @param      command   a specified system command.
     */
    public native static void exec (String command) ;

    /**
     * Sets the device's "APD" time. This is the time in 1/20th seconds where,
     * if no user interaction occurs with the device, it turns off.
     *
     * @param time the time in 1/20th seconds where, if no user interaction occurs with the device, it turns off.
     * @return the previous device's "APD" time.
     */
    public native static int setAPD (int time) ;
    
    /**
     * Allocate a block of memory from the memory heap.
     * If not enough space exists for the new block or the argument size is zero, it returns null.
     * The memory allocated with this method can be freed by System.free method.
     * This method supports the garbage collection feature (if the main class of the project implements
     * Use_GarbageCollection) instead of the native C equivalent.
     *
     * @param      size   the size (in bytes) of the block.
     * @return     A pointer to a block of memory, or null if 0 is specified for size or if there is not enough memory.
     */
    public native static void_p malloc (int size) ;
    
    /**
     * Deallocates a memory block previously allocated by a call of System.malloc.
     *
     * @param      ptr   pointer to the memory block.
     */
    public native static void free (void_p ptr) ;
 }