/*
 * QUSOFT MICROSYSTMES
 * Moka
 * Copyright 2002 Frdric Brown
 */
 
/*
 *  This file is part of Moka.
 *
 *  Moka is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Moka is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Moka; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package moka.x;

import moka.x.GEM;
import moka.event.EventListener;

/**
 * Component is the base class for user-interface objects.
 *
 * @author  Frdric Brown
 * @version 1.0, 2002-10-31
 * @since   MDK1.0a
 */
public class Component extends EventListener {
	
	/** The image of the component to be displayed.*/
	private BITMAP_p img;
	
	/** Is the component need to be repainted ?*/
	private boolean repaint;
	
	/** The next component in the container of this Component.*/
	protected Component next;
	
	/** The previous component in the container of this Component.*/
	protected Component prev;
	
	/** The parent Container of this Component.*/
	protected Container parent;
	
	/** The height of this Component. Should be only read.*/
	public short height;
	/** The width of this Component. Should be only read.*/
	public short width;
	/** The horizontal coordinate of this Component. Should be only read.*/
	public short x;
	/** The vertical coordinate of this Component. Should be only read.*/
	public short y;
	
	/** Is the Component visible ? Should be only read.*/
	public boolean visible;
	
	/** Is the Component enabled ? Should be only read.*/
	public boolean enabled;
	
	/** The mnemonic associated with this component.*/
	public char mnemonic;
	
	/** The event listener for this component.*/
	public EventListener listen;
	
	/**
	 * Constructs a newly allocated Component.
	 */
	public Component () {
	}
	
    /**
     * Invoked when an event is triggered.
     *
     * @param sender The object who triggered the event.
     */
	public void eventTriggered(Object sender) {
		
	}
	
    /**
     * Free the memory and system ressources used by this Component.
     */
	public native void finalize () ;

	/**
	 * Called when a PaintEvent occurs to paint the image of the component and
	 * stores it in its virtual memory.  A PaintEvent occurs when the aspect of
	 * the component is altered.
	 */
	public native void onPaint () ;

	/**
	 * This method is called to draw the component.  Subclasses of Component
	 * are encouraged to overrides the <code>paint</code> method.
	 */
	public void paint () {}
	
	/*
	 * Sets the bounds (position and size) of the component.
	 *
	 * @param x the horizontal coordinate.
	 * @param y the vertical coordinate.
	 * @param width the width of the component.
	 * @param height the height of the component.
	 */
	public void setBounds (short x, short y, short width, short height) {

	}
	
	/*
	 * Sets the horizontal coordinate of the component.
	 *
	 * @param x the horizontal coordinate.
	 */
	public void setX (short x) {

	}

	/*
	 * Sets the vertical coordinate of the component.
	 *
	 * @param y the vertical coordinate.
	 */
	public void setY (short y) {

	}
	
	/*
	 * Sets the width of the component.
	 *
	 * @param width the width of the component.
	 */
	public void setWidth (short width) {

	}
	
	/*
	 * Sets the height of the component.
	 *
	 * @param height the height of the component.
	 */
	public void setHeight (short height) {

	}
	
	/*
	 * Sets the position of the component.
	 *
	 * @param x the horizontal coordinate.
	 * @param y the vertical coordinate.
	 */
	public void move (short x, short y) {

	}
	
	/**
	 * Sets the visibility of the component.
	 * 
	 * @param b true if the component should be visible, false otherwize.
	 */
	public void setVisible (boolean b) {		

	}
	
	/**
	 * Sets if the component is enabled or not.
	 * 
	 * @param b true if the component should be enabled, false otherwize.
	 */
	public void setEnabled (boolean b) {		

	}
	
	/**
	 * Sets the mnemonic for this component.
	 * 
	 * @param mnemonic.
	 */
	public void setMnemonic (char mnemonic) {

	}
	
	/**
	 * This method is invoked by the GEM when the user interacts
	 * with the component.
	 */
	public void use () {

	}
	
	/**
	 * Indicates if the cursor is over this component.
	 *
	 * @param x the reference's horizontal coordinate
	 * @param y	the reference's vertical coordinate
	 * @return true if the cursor is over the component, false otherwize.
	 */
	public boolean isCursorOver (short x, short y) {				
		return false;
	}
	
	/*
	 * Centers the component in its parent.
	 */
	public void center() {
	
	}
	
	/*
	 * Sends the component to the top of its parent.
	 */
	public void top() {
	
	}
	
	/*
	 * Sends the component to the bottom of its parent.
	 */
	public void bottom() {
	
	}
	
	/*
	 * Sends the component to the left of its parent.
	 */
	public void left() {
	
	}
	
	/*
	 * Sends the component to the right of its parent.
	 */
	public void right() {

	}
	
	/**
	 * Called to brings a component to the front
	 * of a container.
	 * 
	 * @param c the component to bring to front.
	 * @return this component if it is the component to bring to front, null otherwize.
	 */
	public Component toFront (Component c) {

		
		return null;
	}
	
	/**
	 * Disposes of all ressources used by this component.
	 */
	protected void clean () {
		this.finalize();
	}
	
	/**
	 * Checks if the mnemonic of this component correspond
	 * to the current mnemonic. If it is the case, an event
	 * is triggered.
	 */
	public void checkMnemonic(char m) {

	}
}