/*
 * QUSOFT MICROSYSTMES
 * Moka
 * Copyright 2002 Frdric Brown
 */

/*
 *  This file is part of Moka.
 *
 *  Moka is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Moka is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Moka; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package moka.x;

import moka.x.Component;

/**
 * Container is a component that contains child components.
 *
 * @author  Frdric Brown
 * @version 1.0, 2002-10-31
 * @since   MDK1.0a
 */
public class Container extends Component {

	/** The first component in this Container.*/
	protected Component child;

	/** The last component in this Container.*/
	protected Component tail;

	/**
	 * Constructs a newly allocated Container.
	 */
	public Container () {
	}

	/**
	 * Called when a PaintEvent occurs to paint the image of the container and
	 * stores it in its virtual memory.  The container is painted, then all its
	 * children are and finally its foreground is.  A PaintEvent occurs when the
	 * aspect of the container is altered or any of its children is.
	 */
	public void onPaint () {
	}

	/**
	 * Called when an UpdateEvent occurs.  An update event occurs when a
	 * visible component contained in this container has changed its
	 * appearance.
	 */
	public void onRefresh () {
	}

	/**
	 * Sends a PaintEvent to all the children of this component
	 * that need to be repainted.
	 */
	public void repaintChildren () {
	}

	/**
	 * This method is called to draw the foreground of the
	 * container. This method is called after all the children
	 * of this container are painted.
	 */
	public void paintForeground () {}
	
	/**
	 * Paints the children of this container to the virtual screen.
	 *
	 * param clip The SCR_RECT clip
	 */
	public void paintChildren (SCR_RECT_p clip) {
	}

	/**
	 * This method is invoked by the GEM when the user interacts
	 * with the container.
	 */
	public void use () {
	}

	/**
	 * Checks if the mnemonic of this container correspond
	 * to the current mnemonic. If it is the case, an event
	 * is triggered.
	 */
	public void checkMnemonic(char m) {
	}

	/**
	 * Adds the specified component to this container.
	 *
	 * @param c the component to add to this container.
	 */
	public void add (Component c) {
	}

	/**
	 * Removes the specified component from this container.
	 *
	 * @param c the component to remove from this container
	 */
	public void remove (Component c) {
	}

	/**
	 * Empties the container (removes all its children).
	 */
	public void empty () {
	}

	/**
	 * Called to brings a component to the front
	 * of this container.
	 *
	 * @param c The component to bring to front.
	 * @return This container if it is the component to bring to front or if a child of
	 * 			this container is, null otherwize.
	 */
	public Component toFront (Component c) {
		return null;
	}

	/**
	 * Disposes of all ressources used by this container and
	 * all its children.
	 */
	protected void clean () {
	}
}