/*
 * QUSOFT MICROSYSTMES
 * Moka
 * Copyright 2002 Frdric Brown
 */

/*
 *  This file is part of Moka API.
 *
 *  Moka API is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Moka API is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Moka API; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package moka.x;

import moka.x.CaptionedComponent;
import moka.lang.System;

/**
 * TextArea class is a text entry component.
 *
 * @author  Frdric Brown
 * @version 1.5, 2004-11-14
 * @since   MDK1.0a
 */
public class TextArea extends CaptionedComponent {
	/** The number of character this TextField should accept. Should be > 0.*/
	public short maxLength;

	/** Should the words be warped ? Should be only read.*/
	public boolean warp;

	/** Is the vertical scroll bar should be visible ? Should be only read. Use setVScrollVisible to set value. */
	public boolean vScrollVisible;

    /** The index of the first line. Should be only read. Use setScrollLine to set value. */
    public int scrollLine;
    
    /** Is the text editable ? */
    public boolean editable;
    
    /* The total number of lines. */
    private int totalLines = 0;
    /* The first char visible. */
    private int firstIndex;
    /* The last char visible. */
    private int lastIndex;

	/*
	 * Constructs a new TextArea.
	 */
	public TextArea () {
		this("");
	}

	/*
	 * Constructs a new TextArea specifying its caption.
	 *
	 * @param caption the TextArea's caption.
	 */
	public TextArea (String caption) {
		super(caption);
		this.maxLength = 2048;
		this.warp = true;
		/* Scroll support */
		this.vScrollVisible = false;
		this.scrollLine = 0;
	}

	/**
	 * Sets if the words should be warped.
	 *
	 * @param b true to specify that the words should be warped, false to specify that the words should not be warped
	 */
	public void setWarp(boolean b) {
		this.warp = b;
	}

	/**
	 * Sets if the vertical scroll bar should be visible.
	 *
	 * @param b true to specify that the vertical scroll bar should be visible
	 */
	public void setVScrollVisible(boolean b) {
		this.vScrollVisible = b;

		this.repaint = true;
		if (this.visible && this.parent) {
			this.parent.onRefresh();
		}
	}

	/**
	 * Sets the scroll position. In other words, the first line to be
	 * displayed by the TextArea.
	 *
	 * @param num the number of the first line (should be >= 0 and < to the total number of lines).
	 */
	public void setScrollLine(int num) {
		this.scrollLine = num;

		this.repaint = true;
		if (this.visible && this.parent) {
			this.parent.onRefresh();
		}
	}

	/**
	 * Paints the TextArea.
	 */
	public native void paint() ;

	/**
     * Returns the next token from a specified string to a
     * specified buffer.
     *
	 * @param str The string
	 * @param buf The buffer that will receive the token
     * @return    a pointer after the token in str.
	 */
	private static char[] returnToken (char[] str, char[] buf) {
		return new char[1];
	}

	/**
	 * Prints the text in this TextArea while warping words.
	 *
	 * @param str The text to print
	 * @param x The x position
	 * @param y The y position
	 */
	private native void printTextWarp (char[] str, short x, short y) ;

	/**
	 * Returns the number of characters per line this TextArea displays.
	 *
	 * @return the number of characters per line.
	 */
	private short getNbC() {
		return 0;
	}

	/**
	 * Prints the text in this TextArea without warping words.
	 *
	 * @param str The text to print
	 * @param x The x position
	 * @param y The y position
	 * @param cur The current position
	 */
	private native void printTextNoWarp (char[] str, short x, short y, short cur) ;

	/**
	 * This method is invoked by the GEM when the user interacts
	 * with the TextArea.
	 */
	public void use () {

	}
}